##
##  lzfse.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_base 1.0
%define       V_snap 20230624

#   package information
Name:         lzfse
Summary:      Lempel-Ziv (LZ) Using Finite State Entropy (FSE) Library
URL:          https://github.com/lzfse/lzfse
Vendor:       Apple
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Compression
License:      BSD
Version:      %{V_base}.%{V_snap}
Release:      20230624

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/lzfse/lzfse-%{V_snap}.tar.xz
Patch0:       lzfse.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101

%description
    This is Apple's reference implementation of the LZFSE compressor
    introduced in the Compression library with OS X 10.11 and iOS 9.
    LZFSE is a Lempel-Ziv style data compression algorithm using Finite
    State Entropy coding. It targets similar compression rates at higher
    compression and decompression speed compared to deflate using zlib.

%track
    prog lzfse:base = {
        version   = %{V_base}
        url       = https://github.com/lzfse/lzfse/tags
        regex     = tag/lzfse-(__VER__)
    }
    prog lzfse:snap = {
        version   = %{V_snap}
        url       = http://download.openpkg.org/components/versioned/lzfse/
        regex     = lzfse-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n lzfse
    %patch -p0

%build
    %{l_make} %{l_mflags -O} \
        CC="%{l_cc}" \
        CFLAGS="%{l_cflags -O} -DNDEBUG -std=c99" \
        CPPFLAGS="%{l_cppflags}" \
        LDFLAGS="%{l_ldflags}"

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/lib \
        $RPM_BUILD_ROOT%{l_prefix}/include
    %{l_shtool} install -c -s -m 755 \
        build/bin/lzfse $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 \
        build/bin/liblzfse.a $RPM_BUILD_ROOT%{l_prefix}/lib/
    %{l_shtool} install -c -m 644 \
        src/lzfse.h $RPM_BUILD_ROOT%{l_prefix}/include/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

